@@ -125,6 +125,12 @@ gsk_gl_device_create_atlas_image (GskGpuDevice *device,
                            height);
 }
 
+static void
+gsk_gl_device_make_current (GskGpuDevice *device)
+{
+  gdk_gl_context_make_current (gdk_display_get_gl_context (gsk_gpu_device_get_display (device)));
+}
+
 static void
 gsk_gl_device_finalize (GObject *object)
 {
@@ -151,6 +157,7 @@ gsk_gl_device_class_init (GskGLDeviceClass *klass)
   gpu_device_class->create_atlas_image = gsk_gl_device_create_atlas_image;
   gpu_device_class->create_upload_image = gsk_gl_device_create_upload_image;
   gpu_device_class->create_download_image = gsk_gl_device_create_download_image;
+  gpu_device_class->make_current = gsk_gl_device_make_current;
 
   object_class->finalize = gsk_gl_device_finalize;
 }
@@ -235,7 +242,7 @@ gsk_gl_device_get_for_display (GdkDisplay  *display,
   if (!gdk_gl_context_check_version (context, "3.0", "3.0"))
     {
       g_set_error (error, GDK_GL_ERROR, GDK_GL_ERROR_NOT_AVAILABLE,
-                   _("OpenGL ES 2.0 is not supported by this renderer."));
+                   _("OpenGL ES 3.0 is not supported by this renderer."));
       return NULL;
     }
 
