@@ -134,6 +134,9 @@ struct _GtkSnapshotState {
       GskMaskMode mask_mode;
       GskRenderNode *mask_node;
     } mask;
+    struct {
+      GdkSubsurface *subsurface;
+    } subsurface;
   } data;
 };
 
@@ -1298,7 +1301,7 @@ gtk_snapshot_push_stroke (GtkSnapshot     *snapshot,
                                    gtk_snapshot_clear_stroke);
 
   state->data.stroke.path = gsk_path_ref (path);
-  gsk_stroke_init_copy (&state->data.stroke.stroke, stroke);
+  state->data.stroke.stroke = GSK_STROKE_INIT_COPY (stroke);
 }
 
 static GskRenderNode *
@@ -1931,9 +1934,10 @@ gtk_snapshot_gl_shader_pop_texture (GtkSnapshot *snapshot)
  * on an internal stack.
  *
  * When [method@Gtk.Snapshot.restore] is called, @snapshot will
- * be restored to the saved state. Multiple calls to
- * [method@Snapshot.save] and [class@Snapshot.restore] can be nested;
- * each call to `gtk_snapshot_restore()` restores the state from
+ * be restored to the saved state.
+ *
+ * Multiple calls to [method@Gtk.Snapshot.save] and [method@Gtk.Snapshot.restore]
+ * can be nested; each call to `gtk_snapshot_restore()` restores the state from
  * the matching paired `gtk_snapshot_save()`.
  *
  * It is necessary to clear all saved states with corresponding
@@ -2385,7 +2389,7 @@ gtk_snapshot_append_linear_gradient (GtkSnapshot            *snapshot,
 {
   GskRenderNode *node;
   graphene_rect_t real_bounds;
-  float scale_x, scale_y, dx, dy;
+  float dx, dy;
   const GdkRGBA *first_color;
   gboolean need_gradient = FALSE;
 
@@ -2395,8 +2399,8 @@ gtk_snapshot_append_linear_gradient (GtkSnapshot            *snapshot,
   g_return_if_fail (stops != NULL);
   g_return_if_fail (n_stops > 1);
 
-  gtk_snapshot_ensure_affine (snapshot, &scale_x, &scale_y, &dx, &dy);
-  gtk_graphene_rect_scale_affine (bounds, scale_x, scale_y, dx, dy, &real_bounds);
+  gtk_snapshot_ensure_translate (snapshot, &dx, &dy);
+  graphene_rect_offset_r (bounds, dx, dy, &real_bounds);
 
   first_color = &stops[0].color;
   for (gsize i = 0; i < n_stops; i ++)
@@ -2412,10 +2416,10 @@ gtk_snapshot_append_linear_gradient (GtkSnapshot            *snapshot,
     {
       graphene_point_t real_start_point, real_end_point;
 
-      real_start_point.x = scale_x * start_point->x + dx;
-      real_start_point.y = scale_y * start_point->y + dy;
-      real_end_point.x = scale_x * end_point->x + dx;
-      real_end_point.y = scale_y * end_point->y + dy;
+      real_start_point.x = start_point->x + dx;
+      real_start_point.y = start_point->y + dy;
+      real_end_point.x = end_point->x + dx;
+      real_end_point.y = end_point->y + dy;
 
       node = gsk_linear_gradient_node_new (&real_bounds,
                                            &real_start_point,
@@ -2452,7 +2456,7 @@ gtk_snapshot_append_repeating_linear_gradient (GtkSnapshot            *snapshot,
 {
   GskRenderNode *node;
   graphene_rect_t real_bounds;
-  float scale_x, scale_y, dx, dy;
+  float dx, dy;
   gboolean need_gradient = FALSE;
   const GdkRGBA *first_color;
 
@@ -2462,8 +2466,8 @@ gtk_snapshot_append_repeating_linear_gradient (GtkSnapshot            *snapshot,
   g_return_if_fail (stops != NULL);
   g_return_if_fail (n_stops > 1);
 
-  gtk_snapshot_ensure_affine (snapshot, &scale_x, &scale_y, &dx, &dy);
-  gtk_graphene_rect_scale_affine (bounds, scale_x, scale_y, dx, dy, &real_bounds);
+  gtk_snapshot_ensure_translate (snapshot, &dx, &dy);
+  graphene_rect_offset_r (bounds, dx, dy, &real_bounds);
 
   first_color = &stops[0].color;
   for (gsize i = 0; i < n_stops; i ++)
@@ -2479,10 +2483,10 @@ gtk_snapshot_append_repeating_linear_gradient (GtkSnapshot            *snapshot,
     {
       graphene_point_t real_start_point, real_end_point;
 
-      real_start_point.x = scale_x * start_point->x + dx;
-      real_start_point.y = scale_y * start_point->y + dy;
-      real_end_point.x = scale_x * end_point->x + dx;
-      real_end_point.y = scale_y * end_point->y + dy;
+      real_start_point.x = start_point->x + dx;
+      real_start_point.y = start_point->y + dy;
+      real_end_point.x = end_point->x + dx;
+      real_end_point.y = end_point->y + dy;
 
       node = gsk_repeating_linear_gradient_node_new (&real_bounds,
                                                      &real_start_point,
@@ -2830,3 +2834,42 @@ gtk_snapshot_append_outset_shadow (GtkSnapshot          *snapshot,
 
   gtk_snapshot_append_node_internal (snapshot, node);
 }
+
+static GskRenderNode *
+gtk_snapshot_collect_subsurface (GtkSnapshot      *snapshot,
+                                 GtkSnapshotState *state,
+                                 GskRenderNode   **nodes,
+                                 guint             n_nodes)
+{
+  GskRenderNode *node, *subsurface_node;
+
+  node = gtk_snapshot_collect_default (snapshot, state, nodes, n_nodes);
+  if (node == NULL)
+    return NULL;
+
+  subsurface_node = gsk_subsurface_node_new (node, state->data.subsurface.subsurface);
+  gsk_render_node_unref (node);
+
+  return subsurface_node;
+}
+
+static void
+gtk_snapshot_clear_subsurface (GtkSnapshotState *state)
+{
+  g_object_unref (state->data.subsurface.subsurface);
+}
+
+void
+gtk_snapshot_push_subsurface (GtkSnapshot   *snapshot,
+                              GdkSubsurface *subsurface)
+{
+  const GtkSnapshotState *current_state = gtk_snapshot_get_current_state (snapshot);
+  GtkSnapshotState *state;
+
+  state = gtk_snapshot_push_state (snapshot,
+                                   current_state->transform,
+                                   gtk_snapshot_collect_subsurface,
+                                   gtk_snapshot_clear_subsurface);
+
+  state->data.subsurface.subsurface = g_object_ref (subsurface);
+}
