@@ -298,6 +298,13 @@ add_label_row (GtkInspectorGeneral *gen,
   gtk_list_box_insert (GTK_LIST_BOX (list), row, -1);
 }
 
+static void
+append_gl_extension_row (GtkInspectorGeneral *gen,
+                         const char          *ext)
+{
+  add_check_row (gen, GTK_LIST_BOX (gen->gl_extensions_box), ext, epoxy_has_gl_extension (ext), 0);
+}
+
 #ifdef GDK_WINDOWING_X11
 static void
 append_glx_extension_row (GtkInspectorGeneral *gen,
@@ -374,6 +381,19 @@ init_gl (GtkInspectorGeneral *gen)
       return;
     }
 
+ gdk_gl_context_make_current (gdk_display_get_gl_context (gen->display));
+ append_gl_extension_row (gen, "GL_OES_rgb8_rgba8");
+ append_gl_extension_row (gen, "GL_EXT_abgr");
+ append_gl_extension_row (gen, "GL_EXT_texture_format_BGRA8888");
+ append_gl_extension_row (gen, "GL_EXT_texture_norm16");
+ append_gl_extension_row (gen, "GL_OES_texture_half_float");
+ append_gl_extension_row (gen, "GL_EXT_color_buffer_half_float");
+ append_gl_extension_row (gen, "GL_OES_texture_half_float_linear");
+ append_gl_extension_row (gen, "GL_OES_vertex_half_float");
+ append_gl_extension_row (gen, "GL_OES_texture_float");
+ append_gl_extension_row (gen, "GL_EXT_color_buffer_float");
+ append_gl_extension_row (gen, "GL_OES_texture_float_linear");
+
 #if defined(GDK_WINDOWING_X11) || defined(GDK_WINDOWING_WAYLAND) || (defined(GDK_WINDOWING_WIN32) && defined(GDK_WIN32_ENABLE_EGL))
   EGLDisplay egl_display = get_egl_display (gen->display);
   if (egl_display)
@@ -513,11 +533,12 @@ init_vulkan (GtkInspectorGeneral *gen)
       char *device_name;
       char *api_version;
       char *driver_version;
+      const char *types[] = { "other", "integrated GPU", "discrete GPU", "virtual GPU", "CPU" };
 
       vk_device = gen->display->vk_physical_device;
       vkGetPhysicalDeviceProperties (vk_device, &props);
 
-      device_name = g_strdup_printf ("%s (%d)", props.deviceName, props.deviceType);
+      device_name = g_strdup_printf ("%s (%s)", props.deviceName, types[props.deviceType]);
       api_version = g_strdup_printf ("%d.%d.%d",
                                      VK_VERSION_MAJOR (props.apiVersion),
                                      VK_VERSION_MINOR (props.apiVersion),
